.. scingestor documentation master file, created by
   sphinx-quickstart on Thu Jul 28 17:34:20 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to scingestor's documentation!
======================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   scicat_dataset_ingestor
   scicat_dataset_ingest
   scingestor


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
